@@ -30,9 +30,12 @@ class TermClassifier:
         for document in doc:
             arr = []
             for word in bow:
-                tf = len(re.findall(word, document)) / len(document.split(" "))
-                idf = np.log(len(doc) / len(re.findall(word, features)))
-                arr.append(tf * idf)
+                tf = len(re.findall(word, document)) / len(bow)
+                idf = np.log(1 + len(doc) / 1 + len(re.findall(word, features))) + 1
+                
+                # normalization matrix
+                tfidf = (tf * idf)**2
+                arr.append(np.sqrt(tfidf))
             matrix.append(arr)
 
         return np.array(matrix)
